 /* ++                                                                */
 /*                                                                   */
 /* Copyright (c) 1996-1999 Microsoft Corporation                     */
 /*                                                                   */
 /* Module Name:                                                      */
 /*                                                                   */
 /*   mqmail.cpy                                                      */
 /*                                                                   */
 /* Abstract:                                                         */
 /*                                                                   */
 /*   Master include file for Message Queue Exchange Connector        */
 /*                           or MAPI applications                    */
 /*                                                                   */
 /* --                                                                */
 %dcl #MQMAIL_H char ext;
 %if #MQMAIL_H = '' %then %do;
 %#MQMAIL_H = 'Y';

 %dcl #WINBASE_ char ext;
 %if #WINBASE_ = '' %then %do;
 %include winbase;
 %end;
 %dcl #_wtypes_h__ char ext;
 %if #_wtypes_h__ = '' %then %do;
 %include wtypes;
 %end;

 /*---------------------------------------------------------------- */
 /* mail type-id for queues                                         */
 /*---------------------------------------------------------------- */
 /* 5eadc0d0-7182-11cf-a8ff-0020afb8fb50 */
 DEFINE_GUID (CLSID_MQMailQueueType,
              '5eadc0d0'xu,
              '7182'xu, '11cf'xu,
              'a8'x, 'ff'x, '00'x, '20'x, 'af'x, 'b8'x, 'fb'x, '50'x);

 /*---------------------------------------------------------------- */
 /* recipient type (to, cc, bcc)                                    */
 /*---------------------------------------------------------------- */
 define ordinal MQMailRecipType
   ( MQMailRecip_TO,
     MQMailRecip_CC,
     MQMailRecip_BCC
   ) prec (31);

 /*---------------------------------------------------------------- */
 /* recipient data                                                  */
 /*---------------------------------------------------------------- */
 define structure
   1 MQMailRecip,
     2 szName       type LPSTR,/*display name of recipient */
     2 szQueueLabel type LPSTR,/*queue label of recipient */
     2 szAddress    type LPSTR,
                    /*address, queue-label or user@queue-label */
     2 iType        type MQMailRecipType,
                    /*recipient type (to, cc, bcc) */
     2 pftDeliveryTime type LPFILETIME, /*delivery time (incase in */
                    /* a delivery report recipient list) */
     2 szNonDeliveryReason type LPSTR; /*non-delivery reason (in */
                    /* case in a non-delivery report recipient list) */

 define alias LPMQMailRecip handle MQMailRecip;

 /*---------------------------------------------------------------- */
 /* recipient list                                                  */
 /*---------------------------------------------------------------- */
 define structure
   1 MQMailRecipList,
     2 cRecips type ULONG,/*number of recips */
     2 apRecip pointer;   /*pointer to a block of recip pointers */
 define alias LPMQMailRecipList handle MQMailRecipList;

 /*---------------------------------------------------------------- */
 /* types of value a form field can have                            */
 /*---------------------------------------------------------------- */
 define ordinal MQMailFormFieldType
   ( MQMailFormField_BOOL,    /*boolean data */
     MQMailFormField_STRING,  /*string data */
     MQMailFormField_LONG,    /*long data */
     MQMailFormField_CURRENCY,/*currency data */
     MQMailFormField_DOUBLE   /*double data */
   ) prec(31);

 /*---------------------------------------------------------------- */
 /* union of available types of values                              */
 /*---------------------------------------------------------------- */
 define structure
   1 MQMailFormFieldData union,
     2 b    type BOOL,  /*use when type is MQMailFormField_BOOL     */
     2 lpsz type LPSTR, /*use when type is MQMailFormField_STRING   */
     2 l    type LONG,  /*use when type is MQMailFormField_LONG     */
     2 cy   type CY,    /*use when type is MQMailFormField_CURRENCY */
     2 dbl  type double;/*use when type is MQMailFormField_DOUBLE   */
 define alias LPMQMailFormFieldData handle MQMailFormFieldData;

 /*---------------------------------------------------------------- */
 /* form field                                                      */
 /*---------------------------------------------------------------- */
 define structure
   1 MQMailFormField,
     2 szName type LPSTR,/*name of field */
     2 iType  type MQMailFormFieldType,
              /*type of value (boolean, string) */
     2 Value  type MQMailFormFieldData;
              /*value (union of available types) */
 define alias LPMQMailFormField handle MQMailFormField;

 /*---------------------------------------------------------------- */
 /* list of form fields                                             */
 /*---------------------------------------------------------------- */
 define structure
   1 MQMailFormFieldList,
     2 cFields type ULONG,/*number of fields */
     2 apField pointer;   /*pointer to a block of field pointers */
 define alias LPMQMailFormFieldList handle MQMailFormFieldList;

 /*---------------------------------------------------------------- */
 /*types of EMail */
 /*---------------------------------------------------------------- */
 define ordinal MQMailEMailType
   ( MQMailEMail_MESSAGE,            /*text message */
     MQMailEMail_FORM,               /*form with fields */
     MQMailEMail_TNEF,               /*tnef data */
     MQMailEMail_DELIVERY_REPORT,    /*delivery report */
     MQMailEMail_NON_DELIVERY_REPORT /*non-delivery report */
   ) prec(31);

 /*---------------------------------------------------------------- */
 /*message specific data */
 /*---------------------------------------------------------------- */
 define structure
   1 MQMailMessageData,
     2 szText type LPSTR;/*message text */
 define alias LPMQMailMessageData handle MQMailMessageData;

 /*---------------------------------------------------------------- */
 /* form specific data                                              */
 /*---------------------------------------------------------------- */
 define structure
   1 MQMailFormData,
     2 szName  type LPSTR,/*name of form */
     2 pFields type LPMQMailFormFieldList;/*list of fields */
 define alias LPMQMailFormData handle MQMailFormData;

 /*---------------------------------------------------------------- */
 /* tnef specific data                                              */
 /*---------------------------------------------------------------- */
 define structure
   1 MQMailTnefData,
     2 cbData  type ULONG, /*size of tnef data */
     2 lpbData type LPBYTE;/*tnef data buffer */

 define alias LPMQMailTnefData handle MQMailTnefData;

 /*---------------------------------------------------------------- */
 /* delivery report specific data                                   */
 /*---------------------------------------------------------------- */
 define structure
   1 MQMailDeliveryReportData,
     2 pDeliveredRecips  type LPMQMailRecipList,
                         /*delivered recipients */
     2 szOriginalSubject type LPSTR,
                         /*original mail subject */
     2 pftOriginalDate   type LPFILETIME;
                         /*original mail sending time */

 define alias LPMQMailDeliveryReportData
        handle  MQMailDeliveryReportData;

 /*---------------------------------------------------------------- */
 /* non-delivery report specific data                               */
 /*---------------------------------------------------------------- */
 define alias LPMQMailEMail handle MQMailEMail;

 define structure
   1 MQMailNonDeliveryReportData,
     2 pNonDeliveredRecips type LPMQMailRecipList,
                           /*non-delivered recipients */
     2 pOriginalEMail      type LPMQMailEMail;/*original mail */

 define alias LPMQMailNonDeliveryReportData
        handle MQMailNonDeliveryReportData;

 /*---------------------------------------------------------------- */
 /* EMail basic data and specific form/message data                 */
 /*---------------------------------------------------------------- */
 define structure
 1 MQMailEMail_tag# union,
       3 form type MQMailFormData,
           /*use when type is MQMailEMail_FORM */
       3 message type MQMailMessageData,
           /*use when type is MQMailEMail_MESSAGE */
       3 tnef type MQMailTnefData,/*use when type is MQMailEMail_TNEF */
       3 DeliveryReport type MQMailDeliveryReportData,
           /*use when type is MQMailEMail_DELIVERY_REPORT */
       3 NonDeliveryReport type MQMailNonDeliveryReportData;
           /*use when type is MQMailEMail_NON_DELIVERY_REPORT */

 define structure
   1 MQMailEMail,
     2 pFrom     type LPMQMailRecip,/*sender */
     2 szSubject type LPSTR,/*subject */
     2 fRequestDeliveryReport    type BOOL,
                 /*request delivery report */
     2 fRequestNonDeliveryReport type BOOL,
                 /*request non-delivery report */
     2 pftDate   type LPFILETIME,/*sending time */
     2 pRecips   type LPMQMailRecipList,/*recipients */
     2 iType     type MQMailEMailType,
                 /*type of EMail (message, form, etc...) */
     2 * union,
       3 form    type MQMailFormData,
                 /*use when type is MQMailEMail_FORM */
       3 message type MQMailMessageData,
                 /*use when type is MQMailEMail_MESSAGE */
       3 tnef    type MQMailTnefData,
                 /*use when type is MQMailEMail_TNEF */
       3 DeliveryReport type MQMailDeliveryReportData,
                 /*use when type is MQMailEMail_DELIVERY_REPORT */
       3 NonDeliveryReport type MQMailNonDeliveryReportData,
                 /*use when type is MQMailEMail_NON_DELIVERY_REPORT */
     2 pReserved type LPVOID;/*should be set to NULL */
 /* define alias LPMQMailEMail handle MQMailEMail_tag */

 /*---------------------------------------------------------------- */
 /* creates a falcon message body out of an EMail structure         */
 /*---------------------------------------------------------------- */
 dcl MQMailComposeBody
     entry (type MQMailEMail byaddr,
            type ULONG byaddr,
            type LPBYTE byaddr)
     STDAPI external('MQMailComposeBody');

 /*---------------------------------------------------------------- */
 /* creates an EMail structure out of a falcon message body         */
 /*---------------------------------------------------------------- */
 dcl MQMailParseBody
     entry (type ULONG,
            type LPBYTE,
            type LPMQMailEMail byaddr)
     STDAPI external('MQMailParseBody');

 /*---------------------------------------------------------------- */
 /* frees memory that was allocated by MQMail like *ppEmail in      */
 /* MQMailParseBody or *ppBuffer in MQMailComposeBody.              */
 /*---------------------------------------------------------------- */
 dcl MQMailFreeMemory
     entry (type LPVOID)
     STDAPICALLTYPE external('MQMailFreeMemory');

 %end; /*_MQMAIL_H */
