 /* ++                                                                */
 /*                                                                   */
 /* Copyright (c) 1997-1998 Microsoft Corporation                     */
 /*                                                                   */
 /* Module Name:                                                      */
 /*                                                                   */
 /*   rpcasync.cpy                                                    */
 /*                                                                   */
 /* Abstract:                                                         */
 /*                                                                   */
 /*   This module contains the RPC runtime APIs needed to use         */
 /*   [async] RPC features.                                           */
 /*                                                                   */
 /* --                                                                */

 %dcl #_RPCASYNC_H__ char ext;
 %if #_RPCASYNC_H__ = '' %then %do;
 %#_RPCASYNC_H__ = 'Y';

 define ordinal
   RPC_NOTIFICATION_TYPES
     ( RpcNotificationTypeNone,
       RpcNotificationTypeEvent,
       RpcNotificationTypeApc,
       RpcNotificationTypeIoc,
       RpcNotificationTypeHwnd,
       RpcNotificationTypeCallback
     ) prec(31);

 define ordinal
   RPC_ASYNC_EVENT
     ( RpcCallComplete,
       RpcSendComplete,
       RpcReceiveComplete
     ) prec(31);

 define alias PFN_RPCNOTIFICATION_ROUTINE
        entry (handle RPC_ASYNC_STATE,
               pointer,
               type RPC_ASYNC_EVENT)
        RPC_ENTRY limited;

 define structure
   1 RPC_ASYNC_STATE,
     2 Size             fixed bin(31), /* size of this structure */
     2 Signature        fixed bin(31),
     2 Lock             fixed bin(31),
     2 Flags            fixed bin(31),
     2 StubInfo         pointer,
     2 UserInfo         pointer,
     2 RuntimeInfo      pointer,
     2 Event            type RPC_ASYNC_EVENT,
     2 NotificationType type RPC_NOTIFICATION_TYPES,
     2 u union,
       /* Notification by APC */
       3 APC,
         4 NotificationRoutine        type PFN_RPCNOTIFICATION_ROUTINE,
         4 hThread                    type HANDLE,
       /* Notification by IO completion port */
       3 IOC,
         4 hIOPort                    type HANDLE,
         4 dwNumberOfBytesTransferred type DWORD,
         4 dwCompletionKey            type DWORD,
         4 lpOverlapped               type LPOVERLAPPED,
       /* Notification by window message */
       3 HWND,
         4 hWnd                       type HWND,
         4 Msg                        type UINT,
       /* Notification by event */
       3 hEvent                       type HANDLE,
       /* Notification by callback function */
       /* This option is available only to OLE */
       3 NotificationRoutine          type PFN_RPCNOTIFICATION_ROUTINE,
     2 Reserved (4)                   fixed bin (31);

 define alias PRPC_ASYNC_STATE handle RPC_ASYNC_STATE;

 /* Possible values for Flags */
 dcl RPC_C_NOTIFY_ON_SEND_COMPLETE fixed bin(15) value('1'xn);

 dcl RPC_C_INFINITE_TIMEOUT fixed bin(32) unsigned value(INFINITE);

 dcl RPC_ASYNC_VERSION_1_0 fixed bin (31)
     value (size (: RPC_ASYNC_STATE :) );


 RpcAsyncGetCallHandle: proc (pAsync)
                        returns (pointer byvalue)
                        options (inline reorder) internal;
   dcl pAsync type RPC_ASYNC_STATE byaddr;
   return (pAsync.RuntimeInfo);
 end RpcAsyncGetCallHandle;


 dcl RpcAsyncInitializeHandle
     entry (type RPC_ASYNC_STATE byaddr,
            fixed bin(31))
     returns (type RPC_STATUS byvalue optional)
     RPCRTAPI RPC_ENTRY external('RpcAsyncInitializeHandle');

 dcl RpcAsyncRegisterInfo
     entry (type RPC_ASYNC_STATE byaddr)
     returns (type RPC_STATUS byvalue optional)
     RPCRTAPI RPC_ENTRY external('RpcAsyncRegisterInfo');

 dcl RpcAsyncGetCallStatus
     entry (type RPC_ASYNC_STATE byaddr)
     returns (type RPC_STATUS byvalue optional)
     RPCRTAPI RPC_ENTRY external('RpcAsyncGetCallStatus');

 dcl RpcAsyncCompleteCall
     entry (type RPC_ASYNC_STATE byaddr,
            pointer)
     returns (type RPC_STATUS byvalue optional)
     RPCRTAPI RPC_ENTRY external('RpcAsyncCompleteCall');

 dcl RpcAsyncAbortCall
     entry (type RPC_ASYNC_STATE byaddr,
            fixed bin(31))
     returns (type RPC_STATUS byvalue optional)
     RPCRTAPI RPC_ENTRY external('RpcAsyncAbortCall');

 dcl RpcAsyncCancelCall
     entry (type RPC_ASYNC_STATE byaddr,
            type BOOL)
     returns (type RPC_STATUS byvalue optional)
     RPCRTAPI RPC_ENTRY external('RpcAsyncCancelCall');


 /* Internal APIs */

 dcl I_RpcAsyncSetHandle
     entry (type RPC_MESSAGE byaddr,
            type RPC_ASYNC_STATE byaddr)
     returns (type RPC_STATUS byvalue optional)
     RPCRTAPI RPC_ENTRY external('I_RpcAsyncSetHandle');

 dcl I_RpcAsyncAbortCall
     entry (type RPC_ASYNC_STATE byaddr,
            fixed bin(31))
     returns (type RPC_STATUS byvalue optional)
     RPCRTAPI RPC_ENTRY external('I_RpcAsyncAbortCall');

 %end; /* __RPCASYNC_H__ */

