 /*********************************************************************/
 /*                                                                   */
 /* winnls.cpy -- NLS procedure declarations, constant definitions    */
 /*                   and macros                                      */
 /*                                                                   */
 /* Copyright (c) 1991-1996, Microsoft Corp. All rights reserved.     */
 /*                                                                   */
 /*********************************************************************/


 %dcl #WINNLS_ char ext;
 %if #WINNLS_ = '' %then %do;
 %#WINNLS_ = 'Y';

 %dcl NONLS char ext;
 %if NONLS = '' %then %do;

 /* Pull in WINBASE.CPY if necessary */
 %dcl #WINBASE_ char ext;
 %if #WINBASE_ = '' %then %do;
   %include winbase;
 %end;

 %dcl UNICODE char ext;
 %dcl WINVER fixed ext;


 /***********************************************************/
 /* Constants                                               */
 /*                                                         */
 /* Define all constants for the NLS component here.        */
 /***********************************************************/


 /* String Length Maximums. */

 dcl MAX_LEADBYTES   fixed bin(31) value(12);
     /* 5 ranges, 2 bytes each, 0 term. */
 dcl MAX_DEFAULTCHAR fixed bin(31) value(2);
     /* single or double byte */



 /* MBCS and Unicode Translation Flags. */

 dcl MB_PRECOMPOSED       type DWORD value('00000001'xu);
     /* use precomposed chars */
 dcl MB_COMPOSITE         type DWORD value('00000002'xu);
     /* use composite chars */
 dcl MB_USEGLYPHCHARS     type DWORD value('00000004'xu);
     /* use glyph chars, not ctrl chars */
 dcl MB_ERR_INVALID_CHARS type DWORD value('00000008'xu);
     /* error for invalid chars */

 dcl WC_DEFAULTCHECK      type DWORD value('00000100'xu);
     /* check for default char */
 dcl WC_COMPOSITECHECK    type DWORD value('00000200'xu);
     /* convert composite to precomposed */
 dcl WC_DISCARDNS         type DWORD value('00000010'xu);
     /* discard non-spacing chars */
 dcl WC_SEPCHARS          type DWORD value('00000020'xu);
     /* generate separate chars */
 dcl WC_DEFAULTCHAR       type DWORD value('00000040'xu);
     /* replace w/ default char */

 %if WINVER >= 1280 %then %do;
 dcl WC_NO_BEST_FIT_CHARS type DWORD value('00000400'xu);
     /* do not use best fit chars */
 %end; /* WINVER >= 0x0500 */


 /*  Character Type Flags.  */

 dcl CT_CTYPE1 type DWORD value('00000001'xu);
     /* ctype 1 information */
 dcl CT_CTYPE2 type DWORD value('00000002'xu);
     /* ctype 2 information */
 dcl CT_CTYPE3 type DWORD value('00000004'xu);
     /* ctype 3 information */


 /* CType 1 Flag Bits. */
 dcl C1_UPPER            type WORD value('0001'xu);
     /* upper case */
 dcl C1_LOWER            type WORD value('0002'xu);
     /* lower case */
 dcl C1_DIGIT            type WORD value('0004'xu);
     /* decimal digits */
 dcl C1_SPACE            type WORD value('0008'xu);
     /* spacing characters */
 dcl C1_PUNCT            type WORD value('0010'xu);
     /* punctuation characters */
 dcl C1_CNTRL            type WORD value('0020'xu);
     /* control characters */
 dcl C1_BLANK            type WORD value('0040'xu);
     /* blank           characters */
 dcl C1_XDIGIT           type WORD value('0080'xu);
     /* other digits */
 dcl C1_ALPHA            type WORD value('0100'xu);
     /* any linguistic character */


 /* CType 2 Flag Bits. */

 dcl C2_LEFTTORIGHT      type WORD value('0001'xu);
     /* left to right */
 dcl C2_RIGHTTOLEFT      type WORD value('0002'xu);
     /* right to left */

 dcl C2_EUROPENUMBER     type WORD value('0003'xu);
     /* European number, digit */
 dcl C2_EUROPESEPARATOR  type WORD value('0004'xu);
     /* European numeric separator */
 dcl C2_EUROPETERMINATOR type WORD value('0005'xu);
     /* European numeric terminator */
 dcl C2_ARABICNUMBER     type WORD value('0006'xu);
     /* Arabic number */
 dcl C2_COMMONSEPARATOR  type WORD value('0007'xu);
     /* common numeric separator */

 dcl C2_BLOCKSEPARATOR   type WORD value('0008'xu);
     /* block separator */
 dcl C2_SEGMENTSEPARATOR type WORD value('0009'xu);
     /* segment separator */
 dcl C2_WHITESPACE       type WORD value('000A'xu);
     /* white space */
 dcl C2_OTHERNEUTRAL     type WORD value('000B'xu);
     /* other neutrals */

 dcl C2_NOTAPPLICABLE    type WORD value('0000'xu);
     /* no implicit directionality */


 /* CType 3 Flag Bits. */

 dcl C3_NONSPACING       type WORD value('0001'xu);
     /* nonspacing character */
 dcl C3_DIACRITIC        type WORD value('0002'xu);
     /* diacritic mark */
 dcl C3_VOWELMARK        type WORD value('0004'xu);
     /* vowel mark */
 dcl C3_SYMBOL           type WORD value('0008'xu);
     /* symbols */

 dcl C3_KATAKANA         type WORD value('0010'xu);
     /* katakana character */
 dcl C3_HIRAGANA         type WORD value('0020'xu);
     /* hiragana character */
 dcl C3_HALFWIDTH        type WORD value('0040'xu);
     /* half width character */
 dcl C3_FULLWIDTH        type WORD value('0080'xu);
     /* full width character */
 dcl C3_IDEOGRAPH        type WORD value('0100'xu);
     /* ideographic character */
 dcl C3_KASHIDA          type WORD value('0200'xu);
     /* Arabic kashida character */
 dcl C3_LEXICAL          type WORD value('0400'xu);
     /* lexical character */

 dcl C3_ALPHA            type WORD value('8000'xu);
     /* any linguistic char (C1_ALPHA) */

 dcl C3_NOTAPPLICABLE    type WORD value('0000'xu);
     /* ctype 3 is not applicable */


 /* String Flags. */

 dcl NORM_IGNORECASE           type DWORD value('00000001'xu);
     /* ignore case */
 dcl NORM_IGNORENONSPACE       type DWORD value('00000002'xu);
     /* ignore nonspacing chars */
 dcl NORM_IGNORESYMBOLS        type DWORD value('00000004'xu);
     /* ignore symbols */

 dcl NORM_IGNOREKANATYPE       type DWORD value('00010000'xu);
     /* ignore kanatype */
 dcl NORM_IGNOREWIDTH          type DWORD value('00020000'xu);
     /* ignore width */


 /* Locale Independent Mapping Flags. */

 dcl MAP_FOLDCZONE             type DWORD value('00000010'xu);
     /* fold compatibility zone chars */
 dcl MAP_PRECOMPOSED           type DWORD value('00000020'xu);
     /* convert to precomposed chars */
 dcl MAP_COMPOSITE             type DWORD value('00000040'xu);
     /* convert to composite chars */
 dcl MAP_FOLDDIGITS            type DWORD value('00000080'xu);
     /* all digits to ASCII 0-9 */

 %if WINVER >= 1280 %then %do;
 dcl MAP_EXPAND_LIGATURES      type DWORD value('00002000'xu);
     /* expand all ligatures */
 %end; /* WINVER >= 0x0500 */


 /* Locale Dependent Mapping Flags. */

 dcl LCMAP_LOWERCASE           type DWORD value('00000100'xu);
     /* lower case letters */
 dcl LCMAP_UPPERCASE           type DWORD value('00000200'xu);
     /* upper case letters */
 dcl LCMAP_SORTKEY             type DWORD value('00000400'xu);
     /* WC sort key (normalize) */
 dcl LCMAP_BYTEREV             type DWORD value('00000800'xu);
     /* byte reversal */

 dcl LCMAP_HIRAGANA            type DWORD value('00100000'xu);
     /* map katakana to hiragana */
 dcl LCMAP_KATAKANA            type DWORD value('00200000'xu);
     /* map hiragana to katakana */
 dcl LCMAP_HALFWIDTH           type DWORD value('00400000'xu);
     /* map double byte to single byte */
 dcl LCMAP_FULLWIDTH           type DWORD value('00800000'xu);
     /* map single byte to double byte */

 dcl LCMAP_LINGUISTIC_CASING   type DWORD value('01000000'xu);
     /* use linguistic rules for casing */

 dcl LCMAP_SIMPLIFIED_CHINESE  type DWORD value('02000000'xu);
     /* map traditional chinese to simplified chinese */
 dcl LCMAP_TRADITIONAL_CHINESE type DWORD value('04000000'xu);
     /* map simplified chinese to traditional chinese */


 /*  Language Group Enumeration Flags. */

 dcl LGRPID_INSTALLED          type DWORD value('00000001'xu);
     /* installed language group ids */
 dcl LGRPID_SUPPORTED          type DWORD value('00000002'xu);
     /* supported language group ids */


 /* Locale Enumeration Flags. */

 dcl LCID_INSTALLED            type DWORD value('00000001'xu);
     /* installed locale ids */
 dcl LCID_SUPPORTED            type DWORD value('00000002'xu);
     /* supported locale ids */
 dcl LCID_ALTERNATE_SORTS      type DWORD value('00000004'xu);
     /* alternate sort locale ids */


 /* Code Page Enumeration Flags. */

 dcl CP_INSTALLED              type DWORD value('00000001'xu);
     /* installed code page ids */
 dcl CP_SUPPORTED              type DWORD value('00000002'xu);
     /* supported code page ids */


 /* Sorting Flags.                                                    */
 /*  WORD Sort:    culturally correct sort                            */
 /*                hyphen and apostrophe are special cased            */
 /*                example: "coop" and "co-op" will sort together in  */
 /*                         a list                                    */
 /*                                                                   */
 /*                     co_op     <-------  underscore (symbol)       */
 /*                     coat                                          */
 /*                     comb                                          */
 /*                     coop                                          */
 /*                     co-op     <-------  hyphen (punctuation)      */
 /*                     cork                                          */
 /*                     went                                          */
 /*                     were                                          */
 /*                     we're     <---- apostrophe (punctuation)      */
 /*                                                                   */
 /*                                                                   */
 /*  STRING Sort:  hyphen and apostrophe will sort                    */
 /*                with all other symbols                             */
 /*                                                                   */
 /*                         co-op     <-------  hyphen (punctuation)  */
 /*                         co_op     <-------  underscore (symbol)   */
 /*                         coat                                      */
 /*                         comb                                      */
 /*                         coop                                      */
 /*                         cork                                      */
 /*                         we're     <---  apostrophe (punctuation)  */
 /*                         went                                      */
 /*                         were                                      */


 dcl SORT_STRINGSORT           type DWORD value('00001000'xu);
     /* use string sort method */

 /* Compare String Return Values. */
 dcl CSTR_LESS_THAN            fixed bin (31) value(1);
     /* string 1 less than string 2 */
 dcl CSTR_EQUAL                fixed bin (31) value(2);
     /* string 1 equal to string 2 */
 dcl CSTR_GREATER_THAN         fixed bin (31) value(3);
     /* string 1 greater than string 2 */

 /* Code Page Default Values. */

 dcl CP_ACP        type DWORD value(0);/* default to ANSI code page*/
 dcl CP_OEMCP      type DWORD value(1);/* default to OEM  code page*/
 dcl CP_MACCP      type DWORD value(2);/* default to MAC  code page*/
 dcl CP_THREAD_ACP type DWORD value(3);
                                    /* current thread's ANSI code page*/
 dcl CP_SYMBOL     type DWORD value(42);/* SYMBOL translations     */

 dcl CP_UTF7       type DWORD value(65000);/* UTF-7 translation    */
 dcl CP_UTF8       type DWORD value(65001);/* UTF-8 translation    */

 /*  Country Codes. */

 dcl CTRY_DEFAULT        fixed bin(31) value(0);

 dcl CTRY_ALBANIA        fixed bin(31) value(355); /* Albania         */
 dcl CTRY_ALGERIA        fixed bin(31) value(213); /* Algeria         */
 dcl CTRY_ARGENTINA      fixed bin(31) value(54);  /* Argentina       */
 dcl CTRY_ARMENIA        fixed bin(31) value(374); /* Armenia         */
 dcl CTRY_AUSTRALIA      fixed bin(31) value( 61); /* Australia       */
 dcl CTRY_AUSTRIA        fixed bin(31) value( 43); /* Austria         */
 dcl CTRY_AZERBAIJAN     fixed bin(31) value(994); /* Azerbaijan      */
 dcl CTRY_BAHRAIN        fixed bin(31) value(973); /* Bahrain         */
 dcl CTRY_BELARUS        fixed bin(31) value(375); /* Belarus         */
 dcl CTRY_BELGIUM        fixed bin(31) value( 32); /* Belgium         */
 dcl CTRY_BELIZE         fixed bin(31) value(501); /* Belize          */
 dcl CTRY_BOLIVIA        fixed bin(31) value(591); /* Bolivia         */
 dcl CTRY_BRAZIL         fixed bin(31) value( 55); /* Brazil          */
 dcl CTRY_BRUNEI_DARUSSALAM fixed bin(31) value(673);
                         /* Brunei Darussalam                         */
 dcl CTRY_BULGARIA       fixed bin(31) value(359); /* Bulgaria        */
 dcl CTRY_CANADA         fixed bin(31) value(  2); /* Canada          */
 dcl CTRY_CARIBBEAN      fixed bin(31) value(  1); /* Caribbean       */
 dcl CTRY_CHILE          fixed bin(31) value( 56); /* Chile           */
 dcl CTRY_COLOMBIA       fixed bin(31) value( 57); /* Colombia        */
 dcl CTRY_COSTA_RICA     fixed bin(31) value(506); /* Costa Rica      */
 dcl CTRY_CROATIA        fixed bin(31) value(385); /* Croatia         */
 dcl CTRY_CZECH          fixed bin(31) value( 42); /* Czech Republic  */
 dcl CTRY_DENMARK        fixed bin(31) value( 45); /* Denmark         */
 dcl CTRY_DOMINICAN_REPUBLIC fixed bin(31) value(  1);
                         /* Dominican Republic                        */
 dcl CTRY_ECUADOR        fixed bin(31) value(593); /* Ecuador         */
 dcl CTRY_EGYPT          fixed bin(31) value( 20); /* Egypt           */
 dcl CTRY_EL_SALVADOR    fixed bin(31) value(503); /* El Salvador     */
 dcl CTRY_ESTONIA        fixed bin(31) value(372); /* Estonia         */
 dcl CTRY_FAEROE_ISLANDS fixed bin(31) value(298); /* Faeroe Islands  */
 dcl CTRY_FINLAND        fixed bin(31) value(358); /* Finland         */
 dcl CTRY_FRANCE         fixed bin(31) value( 33); /* France          */
 dcl CTRY_GEORGIA        fixed bin(31) value(995); /* Georgia         */
 dcl CTRY_GERMANY        fixed bin(31) value( 49); /* Germany         */
 dcl CTRY_GREECE         fixed bin(31) value( 30); /* Greece          */
 dcl CTRY_GUATEMALA      fixed bin(31) value(502); /* Guatemala       */
 dcl CTRY_HONDURAS       fixed bin(31) value(504); /* Honduras        */
 dcl CTRY_HONG_KONG      fixed bin(31) value(852); /* Hong Kong       */
 dcl CTRY_HUNGARY        fixed bin(31) value( 36); /* Hungary         */
 dcl CTRY_ICELAND        fixed bin(31) value(354); /* Iceland         */
 dcl CTRY_INDIA          fixed bin(31) value( 91); /* India           */
 dcl CTRY_INDONESIA      fixed bin(31) value( 62); /* Indonesia       */
 dcl CTRY_IRAN           fixed bin(31) value(981); /* Iran            */
 dcl CTRY_IRAQ           fixed bin(31) value(964); /* Iraq            */
 dcl CTRY_IRELAND        fixed bin(31) value(353); /* Ireland         */
 dcl CTRY_ISRAEL         fixed bin(31) value(972); /* Israel          */
 dcl CTRY_ITALY          fixed bin(31) value( 39); /* Italy           */
 dcl CTRY_JAMAICA        fixed bin(31) value(  1); /* Jamaica         */
 dcl CTRY_JAPAN          fixed bin(31) value( 81); /* Japan           */
 dcl CTRY_JORDAN         fixed bin(31) value(962); /* Jordan          */
 dcl CTRY_KAZAKSTAN      fixed bin(31) value(  7); /* Kazakstan       */
 dcl CTRY_KENYA          fixed bin(31) value(254); /* Kenya           */
 dcl CTRY_KUWAIT         fixed bin(31) value(965); /* Kuwait          */
 dcl CTRY_LATVIA         fixed bin(31) value( 71); /* Latvia          */
 dcl CTRY_LEBANON        fixed bin(31) value(961); /* Lebanon         */
 dcl CTRY_LIBYA          fixed bin(31) value(218); /* Libya           */
 dcl CTRY_LIECHTENSTEIN  fixed bin(31) value( 41); /* Liechtenstein   */
 dcl CTRY_LITHUANIA      fixed bin(31) value(370); /* Lithuania       */
 dcl CTRY_LUXEMBOURG     fixed bin(31) value(352); /* Luxembourg      */
 dcl CTRY_MACAU          fixed bin(31) value(853); /* Macau           */
 dcl CTRY_MACEDONIA      fixed bin(31) value(389);
                         /* Republic of Macedonia                     */
 dcl CTRY_MALAYSIA       fixed bin(31) value( 60); /* Malaysia        */
 dcl CTRY_MEXICO         fixed bin(31) value( 52); /* Mexico          */
 dcl CTRY_MONACO         fixed bin(31) value( 33);
                         /* Principality of Monaco                    */
 dcl CTRY_MOROCCO        fixed bin(31) value(212); /* Morocco         */
 dcl CTRY_NETHERLANDS    fixed bin(31) value( 31); /* Netherlands     */
 dcl CTRY_NEW_ZEALAND    fixed bin(31) value( 64); /* New Zealand     */
 dcl CTRY_NICARAGUA      fixed bin(31) value(505); /* Nicaragua       */
 dcl CTRY_NORWAY         fixed bin(31) value( 47); /* Norway          */
 dcl CTRY_OMAN           fixed bin(31) value(968); /* Oman            */
 dcl CTRY_PAKISTAN       fixed bin(31) value( 92);
                         /* Islamic Republic of Pakistan              */
 dcl CTRY_PANAMA         fixed bin(31) value(507); /* Panama          */
 dcl CTRY_PARAGUAY       fixed bin(31) value(595); /* Paraguay        */
 dcl CTRY_PERU           fixed bin(31) value( 51); /* Peru            */
 dcl CTRY_PHILIPPINES    fixed bin(31) value( 63);
                         /* Republic of the Philippines               */
 dcl CTRY_POLAND         fixed bin(31) value( 48); /* Poland          */
 dcl CTRY_PORTUGAL       fixed bin(31) value(351); /* Portugal        */
 dcl CTRY_PRCHINA        fixed bin(31) value( 86);
                         /* Peoples' Republic of China                */
 dcl CTRY_PUERTO_RICO    fixed bin(31) value(  1); /* Puerto Rico     */
 dcl CTRY_QATAR          fixed bin(31) value(974); /* Qatar           */
 dcl CTRY_ROMANIA        fixed bin(31) value( 40); /* Romania         */
 dcl CTRY_RUSSIA         fixed bin(31) value(  7); /* Russia          */
 dcl CTRY_SAUDI_ARABIA   fixed bin(31) value(966); /* Saudi Arabia    */
 dcl CTRY_SERBIA         fixed bin(31) value(381); /* Serbia          */
 dcl CTRY_SINGAPORE      fixed bin(31) value( 65); /* Singapore       */
 dcl CTRY_SLOVAK         fixed bin(31) value( 42); /* Slovak Republic */
 dcl CTRY_SLOVENIA       fixed bin(31) value(386); /* Slovenia        */
 dcl CTRY_SOUTH_AFRICA   fixed bin(31) value( 27); /* South Africa    */
 dcl CTRY_SOUTH_KOREA    fixed bin(31) value( 82); /* South Korea     */
 dcl CTRY_SPAIN          fixed bin(31) value( 34); /* Spain           */
 dcl CTRY_SWEDEN         fixed bin(31) value( 46); /* Sweden          */
 dcl CTRY_SWITZERLAND    fixed bin(31) value( 41); /* Switzerland     */
 dcl CTRY_SYRIA          fixed bin(31) value(963); /* Syria           */
 dcl CTRY_TAIWAN         fixed bin(31) value(886); /* Taiwan          */
 dcl CTRY_TATARSTAN      fixed bin(31) value(  7); /* Tatarstan       */
 dcl CTRY_THAILAND       fixed bin(31) value( 66); /* Thailand        */
 dcl CTRY_TRINIDAD_Y_TOBAGO fixed bin(31) value(  1);
                         /* Trinidad y Tobago                         */
 dcl CTRY_TUNISIA        fixed bin(31) value(216); /* Tunisia         */
 dcl CTRY_TURKEY         fixed bin(31) value( 90); /* Turkey          */
 dcl CTRY_UAE            fixed bin(31) value(971); /* U.A.E.          */
 dcl CTRY_UKRAINE        fixed bin(31) value(380); /* Ukraine         */
 dcl CTRY_UNITED_KINGDOM fixed bin(31) value( 44); /* United Kingdom  */
 dcl CTRY_UNITED_STATES  fixed bin(31) value(  1); /* United States   */
 dcl CTRY_URUGUAY        fixed bin(31) value(598); /* Uruguay         */
 dcl CTRY_UZBEKISTAN     fixed bin(31) value(  7); /* Uzbekistan      */
 dcl CTRY_VENEZUELA      fixed bin(31) value( 58); /* Venezuela       */
 dcl CTRY_VIET_NAM       fixed bin(31) value( 84); /* Viet Nam        */
 dcl CTRY_YEMEN          fixed bin(31) value(967); /* Yemen           */
 dcl CTRY_ZIMBABWE       fixed bin(31) value(263); /* Zimbabwe        */


 /*  Locale Types.                                                    */
 /*                                                                   */
 /*  These types are used for the GetLocaleInfo NLS API routine.      */
 /*                                                                   */
 /*  The following LCTypes may be used in combination with any other  */
 /*  LCTypes.                                                         */
 /*                                                                   */
 /*  LOCALE_NOUSEROVERRIDE is also used in GetTimeFormatW and         */
 /*  GetDateformatW.                                                  */
 /*                                                                   */
 /*  LOCALE_USE_CP_ACP is used in many of the A (Ansi) apis that      */
 /*  need to do string translation.                                   */
 /*                                                                   */
 /*  LOCALE_RETURN_NUMBER will return the result from GetLocaleInfo   */
 /*  as a number instead of a string.  This flag is only valid for    */
 /*  the LCTypes beginning with LOCALE_I.                             */

 dcl LOCALE_NOUSEROVERRIDE       type DWORD value('80000000'xu);
     /* do not use user overrides */
 dcl LOCALE_USE_CP_ACP           type DWORD value('40000000'xu);
     /* use the system ACP */

 %if WINVER >= 1024 %then %do;
 dcl LOCALE_RETURN_NUMBER        type DWORD value('20000000'xu);
     /* return number instead of string */
 %end; /* WINVER >= 0x0400 */

 dcl LOCALE_ILANGUAGE            type DWORD value('00000001'xu);
     /* language id */
 dcl LOCALE_SLANGUAGE            type DWORD value('00000002'xu);
     /* localized name of language */
 dcl LOCALE_SENGLANGUAGE         type DWORD value('00001001'xu);
     /* English name of language */
 dcl LOCALE_SABBREVLANGNAME      type DWORD value('00000003'xu);
     /* abbreviated language name */
 dcl LOCALE_SNATIVELANGNAME      type DWORD value('00000004'xu);
     /* native name of language */

 dcl LOCALE_ICOUNTRY             type DWORD value('00000005'xu);
     /* country code */
 dcl LOCALE_SCOUNTRY             type DWORD value('00000006'xu);
     /* localized name of country */
 dcl LOCALE_SENGCOUNTRY          type DWORD value('00001002'xu);
     /* English name of country */
 dcl LOCALE_SABBREVCTRYNAME      type DWORD value('00000007'xu);
     /* abbreviated country name */
 dcl LOCALE_SNATIVECTRYNAME      type DWORD value('00000008'xu);
     /* native name of country */

 dcl LOCALE_IDEFAULTLANGUAGE     type DWORD value('00000009'xu);
     /* default language id */
 dcl LOCALE_IDEFAULTCOUNTRY      type DWORD value('0000000A'xu);
     /* default country code */
 dcl LOCALE_IDEFAULTCODEPAGE     type DWORD value('0000000B'xu);
     /* default oem code page */
 dcl LOCALE_IDEFAULTANSICODEPAGE type DWORD value('00001004'xu);
     /* default ansi code page */
 dcl LOCALE_IDEFAULTMACCODEPAGE  type DWORD value('00001011'xu);
     /* default mac code page */

 dcl LOCALE_SLIST                type DWORD value('0000000C'xu);
     /* list item separator */
 dcl LOCALE_IMEASURE             type DWORD value('0000000D'xu);
     /* 0 = metric, 1 = US */

 dcl LOCALE_SDECIMAL             type DWORD value('0000000E'xu);
     /* decimal separator */
 dcl LOCALE_STHOUSAND            type DWORD value('0000000F'xu);
     /* thousand separator */
 dcl LOCALE_SGROUPING            type DWORD value('00000010'xu);
     /* digit grouping */
 dcl LOCALE_IDIGITS              type DWORD value('00000011'xu);
     /* number of fractional digits */
 dcl LOCALE_ILZERO               type DWORD value('00000012'xu);
     /* leading zeros for decimal */
 dcl LOCALE_INEGNUMBER           type DWORD value('00001010'xu);
     /* negative number mode */
 dcl LOCALE_SNATIVEDIGITS        type DWORD value('00000013'xu);
     /* native ascii 0-9 */

 dcl LOCALE_SCURRENCY            type DWORD value('00000014'xu);
     /* local monetary symbol */
 dcl LOCALE_SINTLSYMBOL          type DWORD value('00000015'xu);
     /* intl monetary symbol */
 dcl LOCALE_SMONDECIMALSEP       type DWORD value('00000016'xu);
     /* monetary decimal separator */
 dcl LOCALE_SMONTHOUSANDSEP      type DWORD value('00000017'xu);
     /* monetary thousand separator */
 dcl LOCALE_SMONGROUPING         type DWORD value('00000018'xu);
     /* monetary grouping */
 dcl LOCALE_ICURRDIGITS          type DWORD value('00000019'xu);
     /* # local monetary digits */
 dcl LOCALE_IINTLCURRDIGITS      type DWORD value('0000001A'xu);
     /* # intl monetary digits */
 dcl LOCALE_ICURRENCY            type DWORD value('0000001B'xu);
     /* positive currency mode */
 dcl LOCALE_INEGCURR             type DWORD value('0000001C'xu);
     /* negative currency mode */

 dcl LOCALE_SDATE                type DWORD value('0000001D'xu);
     /* date separator */
 dcl LOCALE_STIME                type DWORD value('0000001E'xu);
     /* time separator */
 dcl LOCALE_SSHORTDATE           type DWORD value('0000001F'xu);
     /* short date format string */
 dcl LOCALE_SLONGDATE            type DWORD value('00000020'xu);
     /* long date format string */
 dcl LOCALE_STIMEFORMAT          type DWORD value('00001003'xu);
     /* time format string */
 dcl LOCALE_IDATE                type DWORD value('00000021'xu);
     /* short date format ordering */
 dcl LOCALE_ILDATE               type DWORD value('00000022'xu);
     /* long date format ordering */
 dcl LOCALE_ITIME                type DWORD value('00000023'xu);
     /* time format specifier */
 dcl LOCALE_ITIMEMARKPOSN        type DWORD value('00001005'xu);
     /* time marker position */
 dcl LOCALE_ICENTURY             type DWORD value('00000024'xu);
     /* century format specifier (short date) */
 dcl LOCALE_ITLZERO              type DWORD value('00000025'xu);
     /* leading zeros in time field */
 dcl LOCALE_IDAYLZERO            type DWORD value('00000026'xu);
     /* leading zeros in day field (short date) */
 dcl LOCALE_IMONLZERO            type DWORD value('00000027'xu);
     /* leading zeros in month field (short date) */
 dcl LOCALE_S1159                type DWORD value('00000028'xu);
     /* AM designator */
 dcl LOCALE_S2359                type DWORD value('00000029'xu);
     /* PM designator */

 dcl LOCALE_ICALENDARTYPE        type DWORD value('00001009'xu);
     /* type of calendar specifier */
 dcl LOCALE_IOPTIONALCALENDAR    type DWORD value('0000100B'xu);
     /* additional calendar types specifier */
 dcl LOCALE_IFIRSTDAYOFWEEK      type DWORD value('0000100C'xu);
     /* first day of week specifier */
 dcl LOCALE_IFIRSTWEEKOFYEAR     type DWORD value('0000100D'xu);
     /* first week of year specifier */

 dcl LOCALE_SDAYNAME1            type DWORD value('0000002A'xu);
     /* long name for Monday */
 dcl LOCALE_SDAYNAME2            type DWORD value('0000002B'xu);
     /* long name for Tuesday */
 dcl LOCALE_SDAYNAME3            type DWORD value('0000002C'xu);
     /* long name for Wednesday */
 dcl LOCALE_SDAYNAME4            type DWORD value('0000002D'xu);
     /* long name for Thursday */
 dcl LOCALE_SDAYNAME5            type DWORD value('0000002E'xu);
     /* long name for Friday */
 dcl LOCALE_SDAYNAME6            type DWORD value('0000002F'xu);
     /* long name for Saturday */
 dcl LOCALE_SDAYNAME7            type DWORD value('00000030'xu);
     /* long name for Sunday */
 dcl LOCALE_SABBREVDAYNAME1      type DWORD value('00000031'xu);
     /* abbreviated name for Monday */
 dcl LOCALE_SABBREVDAYNAME2      type DWORD value('00000032'xu);
     /* abbreviated name for Tuesday */
 dcl LOCALE_SABBREVDAYNAME3      type DWORD value('00000033'xu);
     /* abbreviated name for Wednesday */
 dcl LOCALE_SABBREVDAYNAME4      type DWORD value('00000034'xu);
     /* abbreviated name for Thursday */
 dcl LOCALE_SABBREVDAYNAME5      type DWORD value('00000035'xu);
     /* abbreviated name for Friday */
 dcl LOCALE_SABBREVDAYNAME6      type DWORD value('00000036'xu);
     /* abbreviated name for Saturday */
 dcl LOCALE_SABBREVDAYNAME7      type DWORD value('00000037'xu);
     /* abbreviated name for Sunday */
 dcl LOCALE_SMONTHNAME1          type DWORD value('00000038'xu);
     /* long name for January */
 dcl LOCALE_SMONTHNAME2          type DWORD value('00000039'xu);
     /* long name for February */
 dcl LOCALE_SMONTHNAME3          type DWORD value('0000003A'xu);
     /* long name for March */
 dcl LOCALE_SMONTHNAME4          type DWORD value('0000003B'xu);
     /* long name for April */
 dcl LOCALE_SMONTHNAME5          type DWORD value('0000003C'xu);
     /* long name for May */
 dcl LOCALE_SMONTHNAME6          type DWORD value('0000003D'xu);
     /* long name for June */
 dcl LOCALE_SMONTHNAME7          type DWORD value('0000003E'xu);
     /* long name for July */
 dcl LOCALE_SMONTHNAME8          type DWORD value('0000003F'xu);
     /* long name for August */
 dcl LOCALE_SMONTHNAME9          type DWORD value('00000040'xu);
     /* long name for September */
 dcl LOCALE_SMONTHNAME10         type DWORD value('00000041'xu);
     /* long name for October */
 dcl LOCALE_SMONTHNAME11         type DWORD value('00000042'xu);
     /* long name for November */
 dcl LOCALE_SMONTHNAME12         type DWORD value('00000043'xu);
     /* long name for December */
 dcl LOCALE_SMONTHNAME13         type DWORD value('0000100E'xu);
     /* long name for 13th month (if exists) */
 dcl LOCALE_SABBREVMONTHNAME1    type DWORD value('00000044'xu);
     /* abbreviated name for January */
 dcl LOCALE_SABBREVMONTHNAME2    type DWORD value('00000045'xu);
     /* abbreviated name for February */
 dcl LOCALE_SABBREVMONTHNAME3    type DWORD value('00000046'xu);
     /* abbreviated name for March */
 dcl LOCALE_SABBREVMONTHNAME4    type DWORD value('00000047'xu);
     /* abbreviated name for April */
 dcl LOCALE_SABBREVMONTHNAME5    type DWORD value('00000048'xu);
     /* abbreviated name for May */
 dcl LOCALE_SABBREVMONTHNAME6    type DWORD value('00000049'xu);
     /* abbreviated name for June */
 dcl LOCALE_SABBREVMONTHNAME7    type DWORD value('0000004A'xu);
     /* abbreviated name for July */
 dcl LOCALE_SABBREVMONTHNAME8    type DWORD value('0000004B'xu);
     /* abbreviated name for August */
 dcl LOCALE_SABBREVMONTHNAME9    type DWORD value('0000004C'xu);
     /* abbreviated name for September */
 dcl LOCALE_SABBREVMONTHNAME10   type DWORD value('0000004D'xu);
     /* abbreviated name for October */
 dcl LOCALE_SABBREVMONTHNAME11   type DWORD value('0000004E'xu);
     /* abbreviated name for November */
 dcl LOCALE_SABBREVMONTHNAME12   type DWORD value('0000004F'xu);
     /* abbreviated name for December */
 dcl LOCALE_SABBREVMONTHNAME13   type DWORD value('0000100F'xu);
     /* abbreviated name for 13th month (if exists) */

 dcl LOCALE_SPOSITIVESIGN          type DWORD value('00000050'xu);
     /* positive sign */
 dcl LOCALE_SNEGATIVESIGN          type DWORD value('00000051'xu);
     /* negative sign */
 dcl LOCALE_IPOSSIGNPOSN           type DWORD value('00000052'xu);
     /* positive sign position */
 dcl LOCALE_INEGSIGNPOSN           type DWORD value('00000053'xu);
     /* negative sign position */
 dcl LOCALE_IPOSSYMPRECEDES        type DWORD value('00000054'xu);
     /* mon sym precedes pos amt */
 dcl LOCALE_IPOSSEPBYSPACE         type DWORD value('00000055'xu);
     /* mon sym sep by space from pos amt */
 dcl LOCALE_INEGSYMPRECEDES        type DWORD value('00000056'xu);
     /* mon sym precedes neg amt */
 dcl LOCALE_INEGSEPBYSPACE         type DWORD value('00000057'xu);
     /* mon sym sep by space from neg amt */

 %if (WINVER >= 1024) %then %do;
 dcl LOCALE_FONTSIGNATURE          type DWORD value('00000058'xu);
     /* font signature */
 dcl LOCALE_SISO639LANGNAME        type DWORD value('00000059'xu);
     /* ISO abbreviated language name */
 dcl LOCALE_SISO3166CTRYNAME       type DWORD value('0000005A'xu);
     /* ISO abbreviated country name */
 %end; /* WINVER >= 0x0400 */

 %if (WINVER >= 1280) %then %do;
 dcl LOCALE_IDEFAULTEBCDICCODEPAGE type DWORD value('00001012'xu);
     /* default ebcdic code page */
 dcl LOCALE_IPAPERSIZE             type DWORD value('0000100A'xu);
     /* 1 = letter, 5 = legal, 8 = a3, 9 = a4 */
 dcl LOCALE_SENGCURRNAME           type DWORD value('00001007'xu);
     /* english name of currency */
 dcl LOCALE_SNATIVECURRNAME        type DWORD value('00001008'xu);
     /* native name of currency */
 dcl LOCALE_SYEARMONTH             type DWORD value('00001006'xu);
     /* year month format string */
 dcl LOCALE_SSORTNAME              type DWORD value('00001013'xu);
     /* sort name */
 dcl LOCALE_IDIGITSUBSTITUTION     type DWORD value('00001014'xu);
     /* 0 = context, 1 = none, 2 = national */
 %end; /* WINVER >= 0x0500 */


 /* Time Flags for GetTimeFormatW. */

 dcl TIME_NOMINUTESORSECONDS     type DWORD value('00000001'xu);
     /* do not use minutes or seconds */
 dcl TIME_NOSECONDS              type DWORD value('00000002'xu);
     /* do not use seconds */
 dcl TIME_NOTIMEMARKER           type DWORD value('00000004'xu);
     /* do not use time marker */
 dcl TIME_FORCE24HOURFORMAT      type DWORD value('00000008'xu);
     /* always use 24 hour format */


 /* Date Flags for GetDateFormatW. */

 dcl DATE_SHORTDATE              type DWORD value('00000001'xu);
     /* use short date picture */
 dcl DATE_LONGDATE               type DWORD value('00000002'xu);
     /* use long date picture */
 dcl DATE_USE_ALT_CALENDAR       type DWORD value('00000004'xu);
     /* use alternate calendar (if any) */

 %if (WINVER >= 1280) %then %do;
 dcl DATE_YEARMONTH              type DWORD value('00000008'xu);
     /* use year month picture */
 dcl DATE_LTRREADING             type DWORD value('00000010'xu);
     /* add marks for left to right reading order layout */
 dcl DATE_RTLREADING             type DWORD value('00000020'xu);
     /* add marks for right to left reading order layout */
 %end; /* WINVER >= 0x0500 */

 /*  Calendar Types.                                                  */
 /*                                                                   */
 /*  These types are used for the GetALTCalendarInfoW                 */
 /*  NLS API routine.                                                 */
 /*  Some of these types are also used for the SetCalendarInfo        */
 /*  NLS API routine.                                                 */

 /*  The following CalTypes may be used in combination with any other */
 /*  CalTypes.                                                        */
 /*                                                                   */
 /*    CAL_NOUSEROVERRIDE                                             */
 /*                                                                   */
 /*    CAL_USE_CP_ACP is used in the A (Ansi) apis that need to do    */
 /*    string translation.                                            */
 /*                                                                   */
 /*    CAL_RETURN_NUMBER will return the result from GetCalendarInfo  */
 /*    as a number instead of a string.                               */
 /*    This flag is only valid for the CalTypes beginning with CAL_I. */

 %if (WINVER >= 1280) %then %do;
 dcl CAL_NOUSEROVERRIDE      type DWORD value(LOCALE_NOUSEROVERRIDE);
     /* do not use user overrides */
 dcl CAL_USE_CP_ACP          type DWORD value(LOCALE_USE_CP_ACP);
     /* use the system ACP */
 dcl CAL_RETURN_NUMBER       type DWORD value(LOCALE_RETURN_NUMBER);
     /* return number instead of string */
 %end; /* WINVER >= 0x0500 */


 /*  The following CalTypes are mutually exclusive in that they may */
 /*  NOT be used in combination with each other.                    */

 dcl CAL_ICALINTVALUE            type DWORD value('00000001'xu);
     /* calendar type */
 dcl CAL_SCALNAME                type DWORD value('00000002'xu);
     /* native name of calendar */
 dcl CAL_IYEAROFFSETRANGE        type DWORD value('00000003'xu);
     /* starting years of eras */
 dcl CAL_SERASTRING              type DWORD value('00000004'xu);
     /* era name for IYearOffsetRanges */
 dcl CAL_SSHORTDATE              type DWORD value('00000005'xu);
     /* short date format string */
 dcl CAL_SLONGDATE               type DWORD value('00000006'xu);
     /* long date format string */
 dcl CAL_SDAYNAME1               type DWORD value('00000007'xu);
     /* native name for Monday */
 dcl CAL_SDAYNAME2               type DWORD value('00000008'xu);
     /* native name for Tuesday */
 dcl CAL_SDAYNAME3               type DWORD value('00000009'xu);
     /* native name for Wednesday */
 dcl CAL_SDAYNAME4               type DWORD value('0000000a'xu);
     /* native name for Thursday */
 dcl CAL_SDAYNAME5               type DWORD value('0000000b'xu);
     /* native name for Friday */
 dcl CAL_SDAYNAME6               type DWORD value('0000000c'xu);
     /* native name for Saturday */
 dcl CAL_SDAYNAME7               type DWORD value('0000000d'xu);
     /* native name for Sunday */
 dcl CAL_SABBREVDAYNAME1         type DWORD value('0000000e'xu);
     /* abbreviated name for Monday */
 dcl CAL_SABBREVDAYNAME2         type DWORD value('0000000f'xu);
     /* abbreviated name for Tuesday */
 dcl CAL_SABBREVDAYNAME3         type DWORD value('00000010'xu);
     /* abbreviated name for Wednesday */
 dcl CAL_SABBREVDAYNAME4         type DWORD value('00000011'xu);
     /* abbreviated name for Thursday */
 dcl CAL_SABBREVDAYNAME5         type DWORD value('00000012'xu);
     /* abbreviated name for Friday */
 dcl CAL_SABBREVDAYNAME6         type DWORD value('00000013'xu);
     /* abbreviated name for Saturday */
 dcl CAL_SABBREVDAYNAME7         type DWORD value('00000014'xu);
     /* abbreviated name for Sunday */
 dcl CAL_SMONTHNAME1             type DWORD value('00000015'xu);
     /* native name for January */
 dcl CAL_SMONTHNAME2             type DWORD value('00000016'xu);
     /* native name for February */
 dcl CAL_SMONTHNAME3             type DWORD value('00000017'xu);
     /* native name for March */
 dcl CAL_SMONTHNAME4             type DWORD value('00000018'xu);
     /* native name for April */
 dcl CAL_SMONTHNAME5             type DWORD value('00000019'xu);
     /* native name for May */
 dcl CAL_SMONTHNAME6             type DWORD value('0000001a'xu);
     /* native name for June */
 dcl CAL_SMONTHNAME7             type DWORD value('0000001b'xu);
     /* native name for July */
 dcl CAL_SMONTHNAME8             type DWORD value('0000001c'xu);
     /* native name for August */
 dcl CAL_SMONTHNAME9             type DWORD value('0000001d'xu);
     /* native name for September */
 dcl CAL_SMONTHNAME10            type DWORD value('0000001e'xu);
     /* native name for October */
 dcl CAL_SMONTHNAME11            type DWORD value('0000001f'xu);
     /* native name for November */
 dcl CAL_SMONTHNAME12            type DWORD value('00000020'xu);
     /* native name for December */
 dcl CAL_SMONTHNAME13            type DWORD value('00000021'xu);
     /* native name for 13th month (if any) */
 dcl CAL_SABBREVMONTHNAME1       type DWORD value('00000022'xu);
     /* abbreviated name for January */
 dcl CAL_SABBREVMONTHNAME2       type DWORD value('00000023'xu);
     /* abbreviated name for February */
 dcl CAL_SABBREVMONTHNAME3       type DWORD value('00000024'xu);
     /* abbreviated name for March */
 dcl CAL_SABBREVMONTHNAME4       type DWORD value('00000025'xu);
     /* abbreviated name for April */
 dcl CAL_SABBREVMONTHNAME5       type DWORD value('00000026'xu);
     /* abbreviated name for May */
 dcl CAL_SABBREVMONTHNAME6       type DWORD value('00000027'xu);
     /* abbreviated name for June */
 dcl CAL_SABBREVMONTHNAME7       type DWORD value('00000028'xu);
     /* abbreviated name for July */
 dcl CAL_SABBREVMONTHNAME8       type DWORD value('00000029'xu);
     /* abbreviated name for August */
 dcl CAL_SABBREVMONTHNAME9       type DWORD value('0000002a'xu);
     /* abbreviated name for September */
 dcl CAL_SABBREVMONTHNAME10      type DWORD value('0000002b'xu);
     /* abbreviated name for October */
 dcl CAL_SABBREVMONTHNAME11      type DWORD value('0000002c'xu);
     /* abbreviated name for November */
 dcl CAL_SABBREVMONTHNAME12      type DWORD value('0000002d'xu);
     /* abbreviated name for December */
 dcl CAL_SABBREVMONTHNAME13      type DWORD value('0000002e'xu);
     /* abbreviated name for 13th month (if any) */


 %if (WINVER >= 1280) %then %do;
 dcl CAL_SYEARMONTH           type DWORD value('0000002f'xu);
     /* year month format string */
 dcl CAL_ITWODIGITYEARMAX     type DWORD value('00000030'xu);
     /* two digit year max */
 %end; /* WINVER >= 0x0500 */

 /* Calendar Enumeration Value. */

 dcl ENUM_ALL_CALENDARS       type DWORD value('ffffffff'xu);
     /* enumerate all calendars */


 /* Calendar ID Values. */

 dcl CAL_GREGORIAN                  type DWORD value( 1);
     /* Gregorian (localized) calendar */
 dcl CAL_GREGORIAN_US               type DWORD value( 2);
     /* Gregorian (U.S.) calendar */
 dcl CAL_JAPAN                      type DWORD value( 3);
     /* Japanese Emperor Era calendar */
 dcl CAL_TAIWAN                     type DWORD value( 4);
     /* Republic of China Era calendar */
 dcl CAL_KOREA                      type DWORD value( 5);
     /* Korean Tangun Era calendar */
 dcl CAL_HIJRI                      type DWORD value( 6);
     /* Hijri (Arabic Lunar) calendar */
 dcl CAL_THAI                       type DWORD value( 7);
     /* Thai calendar */
 dcl CAL_HEBREW                     type DWORD value( 8);
     /* Hebrew calendar */
 dcl CAL_GREGORIAN_ME_FRENCH        type DWORD value( 9);
     /* Gregorian Middle East French calendar */
 dcl CAL_GREGORIAN_ARABIC           type DWORD value(10);
     /* Gregorian Arabic calendar */
 dcl CAL_GREGORIAN_XLIT_ENGLISH     type DWORD value(11);
     /* Gregorian Transliterated English calendar */
 dcl CAL_GREGORIAN_XLIT_FRENCH      type DWORD value(12);
     /* Gregorian Transliterated French calendar */

 /*  Language Group ID Values. */

 dcl LGRPID_WESTERN_EUROPE          type WORD value('0001'xu);
     /* Western Europe & U.S. */
 dcl LGRPID_CENTRAL_EUROPE          type WORD value('0002'xu);
     /* Central Europe */
 dcl LGRPID_BALTIC                  type WORD value('0003'xu);
     /* Baltic */
 dcl LGRPID_GREEK                   type WORD value('0004'xu);
     /* Greek */
 dcl LGRPID_CYRILLIC                type WORD value('0005'xu);
     /* Cyrillic */
 dcl LGRPID_TURKISH                 type WORD value('0006'xu);
     /* Turkish */
 dcl LGRPID_JAPANESE                type WORD value('0007'xu);
     /* Japanese */
 dcl LGRPID_KOREAN                  type WORD value('0008'xu);
     /* Korean */
 dcl LGRPID_TRADITIONAL_CHINESE     type WORD value('0009'xu);
     /* Traditional Chinese */
 dcl LGRPID_SIMPLIFIED_CHINESE      type WORD value('000a'xu);
     /* Simplified Chinese */
 dcl LGRPID_THAI                    type WORD value('000b'xu);
     /* Thai */
 dcl LGRPID_HEBREW                  type WORD value('000c'xu);
     /* Hebrew */
 dcl LGRPID_ARABIC                  type WORD value('000d'xu);
     /* Arabic */
 dcl LGRPID_VIETNAMESE              type WORD value('000e'xu);
     /* Vietnamese */
 dcl LGRPID_INDIC                   type WORD value('000f'xu);
     /* Indic */
 dcl LGRPID_GEORGIAN                type WORD value('0010'xu);
     /* Georgian */
 dcl LGRPID_ARMENIAN                type WORD value('0011'xu);
     /* Armenian */


 /*****************************************************************/
 /*     Typedefs                                                  */
 /*                                                               */
 /* Define all types for the NLS component here.                  */
 /*****************************************************************/

 /*  Language Group ID. */

 define alias LGRPID  type DWORD;

 /* Locale type constant. */

 define alias LCTYPE  type DWORD;


 /* Calendar type constant. */

 define alias CALTYPE type DWORD;


 /* Calendar ID. */

 define alias CALID   type DWORD;


 /* CP Info. */

 define structure
   1 CPINFO,
     2 MaxCharSize type UINT,/* max length (bytes) of a char */
     2 DefaultChar (MAX_DEFAULTCHAR) type BYTE, /* default character */
     2 LeadByte    (MAX_LEADBYTES)   type BYTE; /* lead byte ranges  */
 define alias LPCPINFO handle CPINFO;

 define structure
   1 CPINFOEXA,
     2 MaxCharSize        type UINT,
       /* max length (in bytes) of a char */
     2 DefaultChar (MAX_DEFAULTCHAR) type BYTE,
       /* default character (MB) */
     2 LeadByte (MAX_LEADBYTES) type BYTE,
       /* lead byte ranges */
     2 UnicodeDefaultChar WCHAR,
       /* default character (Unicode) */
     2 CodePage           type UINT,
       /* code page id */
     2 CodePageName       char (MAX_PATH - 1) varz;
       /* code page name (Unicode) ??? */
 define alias LPCPINFOEXA handle CPINFOEXA;

 define structure
   1 CPINFOEXW,
     2 MaxCharSize        type UINT,
       /* max length (in bytes) of a char */
     2 DefaultChar (MAX_DEFAULTCHAR) type BYTE,
       /* default character (MB) */
     2 LeadByte (MAX_LEADBYTES) type BYTE,
       /* lead byte ranges */
     2 UnicodeDefaultChar WCHAR,
       /* default character (Unicode) */
     2 CodePage           type UINT,
       /* code page id */
     2 CodePageName       WCHAR (MAX_PATH - 1) varz;
       /* code page name (Unicode) */
 define alias LPCPINFOEXW handle CPINFOEXW;

 %if UNICODE ^= '' %then %do;
   define alias   CPINFOEX type   CPINFOEXW;
   define alias LPCPINFOEX type LPCPINFOEXW;
 %end; %else %do;
   define alias   CPINFOEX type   CPINFOEXA;
   define alias LPCPINFOEX type LPCPINFOEXA;
 %end; /* UNICODE */

 /* Number format. */

 define structure
   1 NUMBERFMTA,
     2 NumDigits     type UINT,  /* number of decimal digits          */
     2 LeadingZero   type UINT,  /* if leading zero in decimal fields */
     2 Grouping      type UINT,  /* group size left of decimal        */
     2 lpDecimalSep  type LPSTR, /* ptr to decimal separator string   */
     2 lpThousandSep type LPSTR, /* ptr to thousand separator string  */
     2 NegativeOrder type UINT;  /* negative number ordering          */
 define alias LPNUMBERFMTA handle NUMBERFMTA;

 define structure
   1 NUMBERFMTW,
     2 NumDigits     type UINT,  /* number of decimal digits          */
     2 LeadingZero   type UINT,  /* if leading zero in decimal fields */
     2 Grouping      type UINT,  /* group size left of decimal        */
     2 lpDecimalSep  type LPWSTR,/* ptr to decimal separator string   */
     2 lpThousandSep type LPWSTR,/* ptr to thousand separator string  */
     2 NegativeOrder type UINT;  /* negative number ordering          */
 define alias LPNUMBERFMTW handle NUMBERFMTW;

 %if UNICODE ^= '' %then %do;
   define alias   NUMBERFMT type   NUMBERFMTW;
   define alias LPNUMBERFMT type LPNUMBERFMTW;
 %end; %else %do;
   define alias   NUMBERFMT type   NUMBERFMTA;
   define alias LPNUMBERFMT type LPNUMBERFMTA;
 %end; /* UNICODE */


 /* Currency format. */

 define structure
   1 CURRENCYFMTA,
    2 NumDigits     type UINT,  /* number of decimal digits           */
    2 LeadingZero   type UINT,  /* if leading zero in decimal fields  */
    2 Grouping      type UINT,  /* group size left of decimal         */
    2 lpDecimalSep  type LPSTR, /* ptr to decimal separator string    */
    2 lpThousandSep type LPSTR, /* ptr to thousand separator string   */
    2 NegativeOrder type UINT,  /* negative currency ordering         */
    2 PositiveOrder type UINT,  /* positive currency ordering         */
    2 lpCurrencySymbol type LPSTR;/* ptr to currency symbol string    */
 define alias LPCURRENCYFMTA handle CURRENCYFMTA;

 define structure
   1 CURRENCYFMTW,
    2 NumDigits     type UINT,  /* number of decimal digits           */
    2 LeadingZero   type UINT,  /* if leading zero in decimal fields  */
    2 Grouping      type UINT,  /* group size left of decimal         */
    2 lpDecimalSep  type LPWSTR,/* ptr to decimal separator string    */
    2 lpThousandSep type LPWSTR,/* ptr to thousand separator string   */
    2 NegativeOrder type UINT,  /* negative currency ordering         */
    2 PositiveOrder type UINT,  /* positive currency ordering         */
    2 lpCurrencySymbol type LPWSTR;/* ptr to currency symbol string   */
 define alias LPCURRENCYFMTW handle CURRENCYFMTW;

 %if UNICODE ^= '' %then %do;
   define alias   CURRENCYFMT type   CURRENCYFMTW;
   define alias LPCURRENCYFMT type LPCURRENCYFMTW;
 %end; %else %do;
   define alias   CURRENCYFMT type   CURRENCYFMTA;
   define alias LPCURRENCYFMT type LPCURRENCYFMTA;
 %end; /* UNICODE */



 /* Enumeration function constants. */

 define alias LANGUAGEGROUP_ENUMPROCA
              entry (type LGRPID,
                     pointer, /* to char (*) varz byaddr */
                     pointer, /* to char (*) varz byaddr */
                     type DWORD)
              returns(type BOOL optional byvalue)
              limited CALLBACK;

 define alias LANGGROUPLOCALE_ENUMPROCA
              entry (type LGRPID,
                     type LCID,
                     pointer) /* to char (*) varz byaddr */
              returns(type BOOL optional byvalue)
              limited CALLBACK;

 define alias UILANGUAGE_ENUMPROCA
              entry (pointer) /* to char (*) varz byaddr */
              returns(type BOOL optional byvalue)
              limited CALLBACK;

 define alias LOCALE_ENUMPROCA
              entry (pointer) /* to char (*) varz byaddr */
              returns(type BOOL optional byvalue)
              limited CALLBACK;

 define alias CODEPAGE_ENUMPROCA
              entry (pointer) /* to char (*) varz byaddr */
              returns(type BOOL optional byvalue)
              limited CALLBACK;

 define alias DATEFMT_ENUMPROCA
              entry (pointer) /* to char (*) varz byaddr */
              returns(type BOOL optional byvalue)
              limited CALLBACK;

 define alias DATEFMT_ENUMPROCEXA
              entry (pointer, /* to char (*) varz byaddr */
                     type CALID)
              returns(type BOOL optional byvalue)
              limited CALLBACK;

 define alias TIMEFMT_ENUMPROCA
              entry (pointer) /* to char (*) varz byaddr */
              returns(type BOOL optional byvalue)
              limited CALLBACK;

 define alias CALINFO_ENUMPROCA
              entry (pointer) /* to char (*) varz byaddr */
              returns(type BOOL optional byvalue)
              limited CALLBACK;

 define alias CALINFO_ENUMPROCEXA
              entry (pointer, /* to char (*) varz byaddr */
                     type CALID)
              returns(type BOOL optional byvalue)
              limited CALLBACK;


 define alias LANGUAGEGROUP_ENUMPROCW
              entry (type LGRPID,
                     pointer, /* to WCHAR (*) varz byaddr */
                     pointer, /* to WCHAR (*) varz byaddr */
                     type DWORD)
              returns(type BOOL optional byvalue)
              limited CALLBACK;

 define alias LANGGROUPLOCALE_ENUMPROCW
              entry (type LGRPID,
                     type LCID,
                     pointer) /* to WCHAR (*) varz byaddr */
              returns(type BOOL optional byvalue)
              limited CALLBACK;

 define alias UILANGUAGE_ENUMPROCW
              entry (pointer) /* to WCHAR (*) varz byaddr */
              returns(type BOOL optional byvalue)
              limited CALLBACK;

 define alias LOCALE_ENUMPROCW
              entry (pointer) /* to WCHAR (*) varz byaddr */
              returns(type BOOL optional byvalue)
              limited CALLBACK;

 define alias CODEPAGE_ENUMPROCW
              entry (pointer) /* to WCHAR (*) varz byaddr */
              returns(type BOOL optional byvalue)
              limited CALLBACK;

 define alias DATEFMT_ENUMPROCW
              entry (pointer) /* to WCHAR (*) varz byaddr */
              returns(type BOOL optional byvalue)
              limited CALLBACK;

 define alias DATEFMT_ENUMPROCEXW
              entry (pointer, /* to WCHAR (*) varz byaddr */
                     type CALID)
              returns(type BOOL optional byvalue)
              limited CALLBACK;

 define alias TIMEFMT_ENUMPROCW
              entry (pointer) /* to WCHAR (*) varz byaddr */
              returns(type BOOL optional byvalue)
              limited CALLBACK;

 define alias CALINFO_ENUMPROCW
              entry (pointer) /* to WCHAR (*) varz byaddr */
              returns(type BOOL optional byvalue)
              limited CALLBACK;

 define alias CALINFO_ENUMPROCEXW
              entry (pointer, /* to WCHAR (*) varz byaddr */
                     type CALID)
              returns(type BOOL optional byvalue)
              limited CALLBACK;


 %if UNICODE ^= '' %then %do;
   define alias LANGUAGEGROUP_ENUMPROC   type LANGUAGEGROUP_ENUMPROCW;
   define alias LANGGROUPLOCALE_ENUMPROC type LANGGROUPLOCALE_ENUMPROCW;
   define alias UILANGUAGE_ENUMPROC      type UILANGUAGE_ENUMPROCW;
   define alias LOCALE_ENUMPROC          type LOCALE_ENUMPROCW;
   define alias CODEPAGE_ENUMPROC        type CODEPAGE_ENUMPROCW;
   define alias DATEFMT_ENUMPROC         type DATEFMT_ENUMPROCW;
   define alias DATEFMT_ENUMPROCEX       type DATEFMT_ENUMPROCEXW;
   define alias TIMEFMT_ENUMPROC         type TIMEFMT_ENUMPROCW;
   define alias CALINFO_ENUMPROC         type CALINFO_ENUMPROCW;
   define alias CALINFO_ENUMPROCEX       type CALINFO_ENUMPROCEXW;
 %end; %else %do;
   define alias LANGUAGEGROUP_ENUMPROC   type LANGUAGEGROUP_ENUMPROCA;
   define alias LANGGROUPLOCALE_ENUMPROC type LANGGROUPLOCALE_ENUMPROCA;
   define alias UILANGUAGE_ENUMPROC      type UILANGUAGE_ENUMPROCA;
   define alias LOCALE_ENUMPROC          type LOCALE_ENUMPROCA;
   define alias CODEPAGE_ENUMPROC        type CODEPAGE_ENUMPROCA;
   define alias DATEFMT_ENUMPROC         type DATEFMT_ENUMPROCA;
   define alias DATEFMT_ENUMPROCEX       type DATEFMT_ENUMPROCEXA;
   define alias TIMEFMT_ENUMPROC         type TIMEFMT_ENUMPROCA;
   define alias CALINFO_ENUMPROC         type CALINFO_ENUMPROCA;
   define alias CALINFO_ENUMPROCEX       type CALINFO_ENUMPROCEXA;
 %end; /* !UNICODE */



 /****************************************************************/
 /* Macros                                                       */
 /*                                                              */
 /* Define all macros for the NLS component here.                */
 /****************************************************************/

 /* there are none */

 /****************************************************************/
 /* Function Prototypes                                          */
 /*                                                              */
 /* Only prototypes for the NLS APIs should go here.             */
 /****************************************************************/


 /* Code Page Dependent APIs. */

 dcl IsValidCodePage
     entry (type UINT)
     returns (type BOOL optional byvalue)
     WINBASEAPI WINAPI ext ('IsValidCodePage');

 dcl GetACP
     entry ()
     returns (type UINT byvalue)
     WINBASEAPI WINAPI ext ('GetACP');

 dcl GetOEMCP
     entry ()
     returns (type UINT byvalue)
     WINBASEAPI WINAPI ext ('GetOEMCP');

 dcl GetCPInfo
     entry (type UINT)
     returns (type BOOL optional byvalue)
     WINBASEAPI WINAPI ext ('GetCPInfo');

 dcl GetCPInfoExA
     entry (type UINT,
            type DWORD,
            type CPINFOEXA byaddr)
     returns (type BOOL optional byvalue)
     WINBASEAPI WINAPI ext ('GetCPInfoExA');

 dcl GetCPInfoExW
     entry (type UINT,
            type DWORD,
            type CPINFOEXW byaddr)
     returns (type BOOL optional byvalue)
     WINBASEAPI WINAPI ext ('GetCPInfoExW');

 %dcl GetCPInfoEx char ext;
 %if UNICODE ^= '' %then %do;
   %GetCPInfoEx='GetCPInfoExW';
 %end; %else %do;
   %GetCPInfoEx='GetCPInfoExA';
 %end; /* !UNICODE */

 dcl IsDBCSLeadByte
     entry (type BYTE)
     returns (type BOOL optional byvalue)
     WINBASEAPI WINAPI ext ('IsDBCSLeadByte');

 dcl IsDBCSLeadByteEx
     entry (type UINT)
     returns (type BOOL optional byvalue)
     WINBASEAPI WINAPI ext ('IsDBCSLeadByteEx');

 dcl MultiByteToWideChar
     entry (type UINT,
            type DWORD,
            char(*) varz byaddr nonasgn,
            fixed bin (31),
            WCHAR(*) varz byaddr optional,
            fixed bin (31))
     returns (fixed bin (31) optional byvalue)
     WINBASEAPI WINAPI ext ('MultiByteToWideChar');

 dcl WideCharToMultiByte
     entry (type UINT,
            type DWORD,
            WCHAR(*) varz byaddr nonasgn,
            fixed bin (31),
            char(*) varz byaddr optional,
            fixed bin (31),
            char(*) varz byaddr nonasgn optional,
            type BOOL byaddr optional)
     returns (fixed bin (31) optional byvalue)
     WINBASEAPI WINAPI ext ('WideCharToMultiByte');


 /* Locale Dependent APIs. */

 dcl CompareStringA
     entry (type LCID,
            type DWORD,
            char(*) varz byaddr nonasgn,
            fixed bin (31),
            char(*) varz byaddr nonasgn,
            fixed bin (31))
     returns (fixed bin (31) optional byvalue)
     WINBASEAPI WINAPI ext ('CompareStringA');

 dcl CompareStringW
     entry (type LCID,
            type DWORD,
            WCHAR(*) varz byaddr nonasgn,
            fixed bin (31),
            WCHAR(*) varz byaddr nonasgn,
            fixed bin (31))
     returns (fixed bin (31) optional byvalue)
     WINBASEAPI WINAPI ext ('CompareStringW');

 %dcl CompareString char ext;
 %if UNICODE ^= '' %then %do;
   %CompareString='CompareStringW';
 %end; %else %do;
   %CompareString='CompareStringA';
 %end; /* !UNICODE */

 dcl LCMapStringA
     entry (type LCID,
            type DWORD,
            char(*) varz byaddr nonasgn,
            fixed bin (31),
            char(*) varz byaddr,
            fixed bin (31))
     returns (fixed bin (31) optional byvalue)
     WINBASEAPI WINAPI ext ('LCMapStringA');

 dcl LCMapStringW
     entry (type LCID,
            type DWORD,
            WCHAR(*) varz byaddr nonasgn,
            fixed bin (31),
            WCHAR(*) varz byaddr,
            fixed bin (31))
     returns (fixed bin (31) optional byvalue)
     WINBASEAPI WINAPI ext ('LCMapStringW');

 %dcl LCMapString char ext;
 %if UNICODE ^= '' %then %do;
   %LCMapString='LCMapStringW';
 %end; %else %do;
   %LCMapString='LCMapStringA';
 %end; /* !UNICODE */


 dcl GetLocaleInfoA
     entry (type LCID,
            type LCTYPE,
            char(*) varz byaddr,
            fixed bin (31))
     returns (fixed bin (31) optional byvalue)
     WINBASEAPI WINAPI ext ('GetLocaleInfoA');

 dcl GetLocaleInfoW
     entry (type LCID,
            type LCTYPE,
            WCHAR(*) varz byaddr,
            fixed bin (31))
     returns (fixed bin (31) optional byvalue)
     WINBASEAPI WINAPI ext ('GetLocaleInfoW');

 %dcl GetLocaleInfo char ext;
 %if UNICODE ^= '' %then %do;
   %GetLocaleInfo='GetLocaleInfoW';
 %end; %else %do;
   %GetLocaleInfo='GetLocaleInfoA';
 %end; /* !UNICODE */


 dcl SetLocaleInfoA
     entry (type LCID,
            type LCTYPE)
     returns (type BOOL optional byvalue)
     WINBASEAPI WINAPI ext ('SetLocaleInfoA');

 dcl SetLocaleInfoW
     entry (type LCID,
            type LCTYPE)
     returns (type BOOL optional byvalue)
     WINBASEAPI WINAPI ext ('SetLocaleInfoW');

 %dcl SetLocaleInfo char ext;
 %if UNICODE ^= '' %then %do;
   %SetLocaleInfo='SetLocaleInfoW';
 %end; %else %do;
   %SetLocaleInfo='SetLocaleInfoA';
 %end; /* !UNICODE */

 dcl GetCalendarInfoA
     entry (type LCID,
            type CALID,
            type CALTYPE,
            char(*) varz byaddr optional,
            fixed bin (31),
            type DWORD byaddr optional)
     returns (fixed bin (31) optional byvalue)
     WINBASEAPI WINAPI ext ('GetCalendarInfoA');

 dcl GetCalendarInfoW
     entry (type LCID,
            type CALID,
            type CALTYPE,
            WCHAR(*) varz byaddr optional,
            fixed bin (31),
            type DWORD byaddr optional)
     returns (fixed bin (31) optional byvalue)
     WINBASEAPI WINAPI ext ('GetCalendarInfoW');

 %dcl GetCalendarInfo char ext;
 %if UNICODE ^= '' %then %do;
   %GetCalendarInfo='GetCalendarInfoW';
 %end; %else %do;
   %GetCalendarInfo='GetCalendarInfoA';
 %end; /* !UNICODE */

 dcl SetCalendarInfoA
     entry (type LCID,
            type CALID,
            type CALTYPE,
            char(*) varz byaddr nonasgn)
     returns (type BOOL optional byvalue)
     WINBASEAPI WINAPI ext ('SetCalendarInfoA');

 dcl SetCalendarInfoW
     entry (type LCID,
            type CALID,
            type CALTYPE,
            WCHAR(*) varz byaddr nonasgn)
     returns (type BOOL optional byvalue)
     WINBASEAPI WINAPI ext ('SetCalendarInfoW');

 %dcl SetCalendarInfo char ext;
 %if UNICODE ^= '' %then %do;
   %SetCalendarInfo='SetCalendarInfoW';
 %end; %else %do;
   %SetCalendarInfo='SetCalendarInfoA';
 %end; /* !UNICODE */


 dcl GetTimeFormatA
     entry (type LCID,
            type DWORD,
            type SYSTEMTIME byaddr nonasgn,
            char(*) varz byaddr nonasgn,
            char(*) varz byaddr,
            fixed bin (31))
     returns (fixed bin (31) optional byvalue)
     WINBASEAPI WINAPI ext ('GetTimeFormatA');

 dcl GetTimeFormatW
     entry (type LCID,
            type DWORD,
            type SYSTEMTIME byaddr nonasgn,
            WCHAR(*) varz byaddr nonasgn,
            WCHAR(*) varz byaddr,
            fixed bin (31))
     returns (fixed bin (31) optional byvalue)
     WINBASEAPI WINAPI ext ('GetTimeFormatW');


 %dcl GetTimeFormat char ext;
 %if UNICODE ^= '' %then %do;
   %GetTimeFormat='GetTimeFormatW';
 %end; %else %do;
   %GetTimeFormat='GetTimeFormatA';
 %end; /* !UNICODE */

 dcl GetDateFormatA
     entry (type LCID,
            type DWORD,
            type SYSTEMTIME byaddr nonasgn,
            char(*) varz byaddr nonasgn,
            char(*) varz byaddr,
            fixed bin (31))
     returns (fixed bin (31) optional byvalue)
     WINBASEAPI WINAPI ext ('GetDateFormatA');

 dcl GetDateFormatW
     entry (type LCID,
            type DWORD,
            type SYSTEMTIME byaddr nonasgn,
            WCHAR(*) varz byaddr nonasgn,
            WCHAR(*) varz byaddr,
            fixed bin (31))
     returns (fixed bin (31) optional byvalue)
     WINBASEAPI WINAPI ext ('GetDateFormatW');

 %dcl GetDateFormat char ext;
 %if UNICODE ^= '' %then %do;
   %GetDateFormat='GetDateFormatW';
 %end; %else %do;
   %GetDateFormat='GetDateFormatA';
 %end; /* !UNICODE */


 dcl GetNumberFormatA
     entry (type LCID,
            type DWORD,
            char(*) varz byaddr nonasgn,
            type NUMBERFMTA byaddr nonasgn,
            char(*) varz byaddr,
            fixed bin (31))
     returns (fixed bin (31) optional byvalue)
     WINBASEAPI WINAPI ext ('GetNumberFormatA');

 dcl GetNumberFormatW
     entry (type LCID,
            type DWORD,
            WCHAR(*) varz byaddr nonasgn,
            type NUMBERFMTW byaddr nonasgn,
            WCHAR(*) varz byaddr,
            fixed bin (31))
     returns (fixed bin (31) optional byvalue)
     WINBASEAPI WINAPI ext ('GetNumberFormatW');

 %dcl GetNumberFormat char ext;
 %if UNICODE ^= '' %then %do;
   %GetNumberFormat='GetNumberFormatW';
 %end; %else %do;
   %GetNumberFormat='GetNumberFormatA';
 %end; /* !UNICODE */

 dcl GetCurrencyFormatA
     entry (type LCID,
            type DWORD,
            char(*) varz byaddr nonasgn,
            type CURRENCYFMTA byaddr nonasgn,
            char(*) varz byaddr,
            fixed bin (31))
     returns (fixed bin (31) optional byvalue)
     WINBASEAPI WINAPI ext ('GetCurrencyFormatA');

 dcl GetCurrencyFormatW
     entry (type LCID,
            type DWORD,
            WCHAR(*) varz byaddr nonasgn,
            type CURRENCYFMTW byaddr nonasgn,
            WCHAR(*) varz byaddr,
            fixed bin (31))
     returns (fixed bin (31) optional byvalue)
     WINBASEAPI WINAPI ext ('GetCurrencyFormatW');

 %dcl GetCurrencyFormat char ext;
 %if UNICODE ^= '' %then %do;
   %GetCurrencyFormat='GetCurrencyFormatW';
 %end; %else %do;
   %GetCurrencyFormat='GetCurrencyFormatA';
 %end; /* !UNICODE */

 dcl EnumCalendarInfoA
     entry (type CALINFO_ENUMPROCA,
            type LCID,
            type CALID)
     returns (type BOOL optional byvalue)
     WINBASEAPI WINAPI ext ('EnumCalendarInfoA');

 dcl EnumCalendarInfoW
     entry (type CALINFO_ENUMPROCW,
            type LCID,
            type CALID)
     returns (type BOOL optional byvalue)
     WINBASEAPI WINAPI ext ('EnumCalendarInfoW');

 %dcl EnumCalendarInfo char ext;
 %if UNICODE ^= '' %then %do;
   %EnumCalendarInfo='EnumCalendarInfoW';
 %end; %else %do;
   %EnumCalendarInfo='EnumCalendarInfoA';
 %end; /* !UNICODE */

 %if (WINVER >= 1280) %then %do;
 dcl EnumCalendarInfoExA
     entry (type CALINFO_ENUMPROCEXA,
            type LCID,
            type CALID,
            type CALTYPE)
     returns (type BOOL optional byvalue)
     WINBASEAPI WINAPI ext ('EnumCalendarInfoExA');

 dcl EnumCalendarInfoExW
     entry (type CALINFO_ENUMPROCEXW,
            type LCID,
            type CALID,
            type CALTYPE)
     returns (type BOOL optional byvalue)
     WINBASEAPI WINAPI ext ('EnumCalendarInfoExW');

 %dcl EnumCalendarInfoEx char ext;
 %if UNICODE ^= '' %then %do;
   %EnumCalendarInfoEx='EnumCalendarInfoExW';
 %end; %else %do;
   %EnumCalendarInfoEx='EnumCalendarInfoExA';
 %end; /* !UNICODE */
 %end; /* WINVER >= 0x0500 */

 dcl EnumTimeFormatsA
     entry (type TIMEFMT_ENUMPROCA,
            type LCID)
     returns (type BOOL optional byvalue)
     WINBASEAPI WINAPI ext ('EnumTimeFormatsA');

 dcl EnumTimeFormatsW
     entry (type TIMEFMT_ENUMPROCW,
            type LCID)
     returns (type BOOL optional byvalue)
     WINBASEAPI WINAPI ext ('EnumTimeFormatsW');

 %dcl EnumTimeFormats char ext;
 %if UNICODE ^= '' %then %do;
   %EnumTimeFormats='EnumTimeFormatsW';
 %end; %else %do;
   %EnumTimeFormats='EnumTimeFormatsA';
 %end; /* !UNICODE */


 dcl EnumDateFormatsA
     entry (type DATEFMT_ENUMPROCA,
            type LCID)
     returns (type BOOL optional byvalue)
     WINBASEAPI WINAPI ext ('EnumDateFormatsA');

 dcl EnumDateFormatsW
     entry (type DATEFMT_ENUMPROCW,
            type LCID)
     returns (type BOOL optional byvalue)
     WINBASEAPI WINAPI ext ('EnumDateFormatsW');

 %dcl EnumDateFormats char ext;
 %if UNICODE ^= '' %then %do;
   %EnumDateFormats='EnumDateFormatsW';
 %end; %else %do;
   %EnumDateFormats='EnumDateFormatsA';
 %end; /* !UNICODE */

 %if (WINVER >= 1280) %then %do;
 dcl EnumDateFormatsExA
     entry (type DATEFMT_ENUMPROCEXA,
            type LCID,
            type DWORD)
     returns (type BOOL optional byvalue)
     WINBASEAPI WINAPI ext ('EnumDateFormatsExA');

 dcl EnumDateFormatsExW
     entry (type DATEFMT_ENUMPROCEXW,
            type LCID,
            type DWORD)
     returns (type BOOL optional byvalue)
     WINBASEAPI WINAPI ext ('EnumDateFormatsExW');

 %dcl EnumDateFormatsEx char ext;
 %if UNICODE ^= '' %then %do;
   %EnumDateFormatsEx='EnumDateFormatsExW';
 %end; %else %do;
   %EnumDateFormatsEx='EnumDateFormatsExA';
 %end; /* !UNICODE */
 %end; /* WINVER >= 0x0500 */


 %if (WINVER >= 1280) %then %do;
 dcl IsValidLanguageGroup
     entry (type LGRPID,
            type DWORD)
     returns (type BOOL optional byvalue)
     WINBASEAPI WINAPI ext ('IsValidLanguageGroup');
 %end; /* WINVER >= 0x0500 */

 dcl IsValidLocale
     entry (type LCID)
     returns (type BOOL byvalue)
     WINBASEAPI WINAPI ext ('IsValidLocale');

 dcl ConvertDefaultLocale
     entry (type LCID)
     returns (type LCID optional byvalue)
     WINBASEAPI WINAPI  ext ('ConvertDefaultLocale');

 dcl GetThreadLocale
     entry ()
     returns (type LCID byvalue)
     WINBASEAPI WINAPI ext ('GetThreadLocale');

 dcl SetThreadLocale
     entry (type LCID)
     returns (type BOOL optional byvalue)
     WINBASEAPI WINAPI ext ('SetThreadLocale');

 %if (WINVER >= 1280) %then %do;
 dcl GetSystemDefaultUILanguage
     entry ()
     returns (type LANGID optional byvalue)
     WINBASEAPI WINAPI ext ('GetSystemDefaultUILanguage');

 dcl GetUserDefaultUILanguage
     entry ()
     returns (type LANGID optional byvalue)
     WINBASEAPI WINAPI ext ('GetUserDefaultUILanguage');
 %end; /* WINVER >= 0x0500 */

 dcl GetSystemDefaultLangID
     entry ()
     returns (type LANGID byvalue)
     WINBASEAPI WINAPI ext ('GetSystemDefaultLangID');

 dcl GetUserDefaultLangID
     entry ()
     returns (type LANGID byvalue)
     WINBASEAPI WINAPI ext ('GetUserDefaultLangID');

 dcl GetSystemDefaultLCID
     entry ()
     returns (type LCID byvalue)
     WINBASEAPI WINAPI ext ('GetSystemDefaultLCID');

 dcl GetUserDefaultLCID
     entry ()
     returns (type LCID byvalue)
     WINBASEAPI WINAPI ext ('GetUserDefaultLCID');


 /* Locale Independent APIs. */

 dcl GetStringTypeExA
     entry (type LCID,
            type DWORD,
            char(*) varz byaddr nonasgn,
            fixed bin (31),
            pointer) /* address of (*) WORD */
      returns (type BOOL optional byvalue)
     WINBASEAPI WINAPI ext ('GetStringTypeExA');

 dcl GetStringTypeExW
     entry (type LCID,
            type DWORD,
            char(*) varz byaddr nonasgn,
            fixed bin (31),
            pointer) /* address of (*) WORD */
     returns (type BOOL optional byvalue)
     WINBASEAPI WINAPI ext ('GetStringTypeExW');

 %dcl GetStringTypeEx char ext;
 %if UNICODE ^= '' %then %do;
   %GetStringTypeEx='GetStringTypeExW';
 %end; %else %do;
   %GetStringTypeEx='GetStringTypeExA';
 %end; /* !UNICODE */


 /*  NOTE: The parameters for GetStringTypeA and GetStringTypeW are  */
 /*        NOT the same.  The W version was shipped in NT 3.1.       */
 /*        A version was then shipped in 16-bit OLE with the wrong   */
 /*        parameters (ported from Win95).  To be compatible, we     */
 /*        must break the relationship between the A and W versions  */
 /*        of GetStringType.  There will be NO function call for the */
 /*        generic GetStringType.                                    */
 /*                                                                  */
 /*        GetStringTypeEx (above) should be used instead.           */

 dcl GetStringTypeA
     entry (type LCID,
            type DWORD,
            char(*) varz byaddr nonasgn,
            fixed bin (31),
            pointer) /* address of (*) WORD */
     returns (type BOOL optional byvalue)
     WINBASEAPI WINAPI ext ('GetStringTypeA');

 dcl GetStringTypeW
     entry (type DWORD,
            char(*) varz byaddr nonasgn,
            fixed bin (31),
            pointer) /* address of (*) WORD */
     returns (type BOOL optional byvalue)
     WINBASEAPI WINAPI ext ('GetStringTypeW');

 dcl FoldStringA
     entry (type DWORD,
            char(*) varz byaddr nonasgn,
            fixed bin (31),
            char(*) varz byaddr,
            fixed bin (31))
     returns (fixed bin (31) optional byvalue)
     WINBASEAPI WINAPI ext ('FoldStringTypeA');

 dcl FoldStringW
     entry (type DWORD,
            WCHAR(*) varz byaddr nonasgn,
            fixed bin (31),
            WCHAR(*) varz byaddr,
            fixed bin (31))
     returns (fixed bin (31) optional byvalue)
     WINBASEAPI WINAPI ext ('FoldStringTypeW');

 %dcl FoldString char ext;
 %if UNICODE ^= '' %then %do;
   %FoldString='FoldStringW';
 %end; %else %do;
   %FoldString='FoldStringA';
 %end; /* !UNICODE */

 %if (WINVER >= 1280) %then %do;
 dcl EnumSystemLanguageGroupsA
     entry (type LANGUAGEGROUP_ENUMPROCA,
            type DWORD)
     returns (type BOOL optional byvalue)
     WINBASEAPI WINAPI ext ('EnumSystemLanguageGroupsA');

 dcl EnumSystemLanguageGroupsW
     entry (type LANGUAGEGROUP_ENUMPROCW,
            type DWORD)
     returns (type BOOL optional byvalue)
     WINBASEAPI WINAPI ext ('EnumSystemLanguageGroupsW');

 %dcl EnumSystemLanguageGroups char ext;
 %if UNICODE ^= '' %then %do;
   %EnumSystemLanguageGroups='EnumSystemLanguageGroupsW';
 %end; %else %do;
   %EnumSystemLanguageGroups='EnumSystemLanguageGroupsA';
 %end; /* !UNICODE */

 dcl EnumLanguageGroupLocalesA
     entry (type LANGGROUPLOCALE_ENUMPROCA,
            type LGRPID,
            type DWORD)
     returns (type BOOL optional byvalue)
     WINBASEAPI WINAPI ext ('EnumLanguageGroupLocalesA');

 dcl EnumLanguageGroupLocalesW
     entry (type LANGGROUPLOCALE_ENUMPROCW,
            type LGRPID,
            type DWORD)
     returns (type BOOL optional byvalue)
     WINBASEAPI WINAPI ext ('EnumLanguageGroupLocalesW');

 %dcl EnumLanguageGroupLocales char ext;
 %if UNICODE ^= '' %then %do;
   %EnumLanguageGroupLocales='EnumLanguageGroupLocalesW';
 %end; %else %do;
   %EnumLanguageGroupLocales='EnumLanguageGroupLocalesA';
 %end; /* !UNICODE */

 dcl EnumUILanguagesA
     entry (type UILANGUAGE_ENUMPROCA,
            type DWORD)
     returns (type BOOL optional byvalue)
     WINBASEAPI WINAPI ext ('EnumUILanguagesA');

 dcl EnumUILanguagesW
     entry (type UILANGUAGE_ENUMPROCW,
            type DWORD)
     returns (type BOOL optional byvalue)
     WINBASEAPI WINAPI ext ('EnumUILanguagesW');

 %dcl EnumUILanguages char ext;
 %if UNICODE ^= '' %then %do;
   %EnumUILanguages='EnumUILanguagesW';
 %end; %else %do;
   %EnumUILanguages='EnumUILanguagesA';
 %end; /* !UNICODE */
 %end; /* WINVER >= 0x0500 */


 dcl EnumSystemLocalesA
     entry (type LOCALE_ENUMPROCA,
            type DWORD)
     returns (type BOOL optional byvalue)
     WINBASEAPI WINAPI ext ('EnumSystemLocalesA');

 dcl EnumSystemLocalesW
     entry (type LOCALE_ENUMPROCW,
            type DWORD)
     returns (type BOOL optional byvalue)
     WINBASEAPI WINAPI ext ('EnumSystemLocalesW');

 %dcl EnumSystemLocales char ext;
 %if UNICODE ^= '' %then %do;
   %EnumSystemLocales='EnumSystemLocalesW';
 %end; %else %do;
   %EnumSystemLocales='EnumSystemLocalesA';
 %end; /* !UNICODE */

 dcl EnumSystemCodePagesA
     entry (type CODEPAGE_ENUMPROCA,
            type DWORD)
     returns (type BOOL optional byvalue)
     WINBASEAPI WINAPI ext ('EnumSystemCodePagesA');

 dcl EnumSystemCodePagesW
     entry (type CODEPAGE_ENUMPROCW,
            type DWORD)
     returns (type BOOL optional byvalue)
     WINBASEAPI WINAPI ext ('EnumSystemCodePagesW');

 %dcl EnumSystemCodePages char ext;
 %if UNICODE ^= '' %then %do;
   %EnumSystemCodePages='EnumSystemCodePagesW';
 %end; %else %do;
   %EnumSystemCodePages='EnumSystemCodePagesA';
 %end; /* !UNICODE */

 %end; /* NONLS */

 %end; /* #WINNLS_ */
